[Scummvm-cvs-logs] CVS: scummvm/scumm string.cpp,1.46,1.47

Jonathan Gray khalek at users.sourceforge.net
Wed Nov 20 05:59:03 CET 2002


Update of /cvsroot/scummvm/scummvm/scumm
In directory sc8-pr-cvs1:/tmp/cvs-serv19887

Modified Files:
	string.cpp 
Log Message:
add top arrow and indy3 to the inventory arrow fix. the spacing and text handling is pretty much identical by the way between indy3 and zak256. the intial code to make the text in both games readable included the original getSpacing I added in which the spacing was based on pixel comparisons of indy3. I see it has been refined somewhat since then :)

Index: string.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/string.cpp,v
retrieving revision 1.46
retrieving revision 1.47
diff -u -d -r1.46 -r1.47
--- string.cpp	20 Nov 2002 13:20:39 -0000	1.46
+++ string.cpp	20 Nov 2002 13:58:23 -0000	1.47
@@ -1125,9 +1125,12 @@
 			}
 		}
 	}
-	
-	// FIXME - this fixes the inventory icons in Zak256, see bug #613109
-	if (_vm->_gameId == GID_ZAK256 && (chr==3 || chr==4))
+
+	// FIXME - this fixes the inventory icons in Zak256/Indy3
+	//  see bug #613109.
+	// chars 1,2: up arrow chars 3,4: down arrow
+	if ((_vm->_gameId == GID_ZAK256 || _vm->_gameId == GID_INDY3_256)
+			&& (chr >= 1 && chr <= 4))
 		spacing = 6;
 	
 	return spacing;





More information about the Scummvm-git-logs mailing list